@@ -134,7 +134,7 @@ def get_fileformat_from_filename(filename):
     )
     if '.' not in filename:
         return None
-    ext = os.path.splitext(filename)[1]
+    ext = os.path.splitext(filename)[1].lower()
     for pattern in patterns:
         if ext in pattern[0]:
             return pattern[1]
@@ -184,8 +184,10 @@ def get_processed_image(f, img, patterns):
         THUMBNAILFIELD_DEFAULT_PROCESS_METHOD = 'thumbnail'
         THUMBNAILFIELD_DEFAULT_PROCESS_OPTIONS = {'filter': Image.ANTIALIAS}
     """
+    if patterns is None:
+        return img
     processed = img.copy()
-    if not isinstance(patterns[0], (list, tuple)):
+    if len(patterns) > 0 and not isinstance(patterns[0], (list, tuple)):
         patterns = [patterns]
     for pattern in patterns:
         width, height, process_method, process_options = _split_pattern(
